@@ -631,7 +631,6 @@ private:
     }
 
     UpdateConnectionStatus();
-
 #endif
   }
 
@@ -747,7 +746,7 @@ public:
     Dialog::PreInit();
   }
 
-  void GetGSPDataCopy(GPSData& data)
+  void GetGPSDataCopy(GPSData& data)
   {
     Lum::OS::Guard<Lum::OS::Mutex> guard(dataMutex);
 
@@ -917,15 +916,13 @@ public:
     else if (model==dataChangedAction && dataChangedAction->IsFinished()) {
       GPSData dataCopy;
 
-      GetGSPDataCopy(dataCopy);
-
+      GetGPSDataCopy(dataCopy);
       ShowChange(dataCopy);
     }
     else if (model==refreshTimer && refreshTimer->IsFinished()) {
       GPSData dataCopy;
 
-      GetGSPDataCopy(dataCopy);
-
+      GetGPSDataCopy(dataCopy);
       ShowChange(dataCopy);
       UpdateStreams(dataCopy);
 
@@ -1060,7 +1057,6 @@ static void cb(struct gps_data_t* data, char * buf, size_t len, int level)
 {
   assert(window!=NULL);
 
-
   Lum::OS::Guard<Lum::OS::Mutex> guard(window->dataMutex);
 
   GPSData                        &gpsData=window->data;
